@@ -110,7 +110,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 1 "../../src/arith.y"
+#line 1 "arith.y"
 
 /*	$NetBSD: arith.y,v 1.15 2002/11/24 22:35:39 christos Exp $	*/
 
@@ -1139,99 +1139,99 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 83 "../../src/arith.y"
+#line 83 "arith.y"
     {
 			return (yyvsp[0]);
 	}
     break;
 
   case 3:
-#line 89 "../../src/arith.y"
+#line 89 "arith.y"
     { yyval = yyvsp[-1]; }
     break;
 
   case 4:
-#line 90 "../../src/arith.y"
+#line 90 "arith.y"
     { yyval = yyvsp[-2] || yyvsp[0]; }
     break;
 
   case 5:
-#line 91 "../../src/arith.y"
+#line 91 "arith.y"
     { yyval = yyvsp[-2] && yyvsp[0]; }
     break;
 
   case 6:
-#line 92 "../../src/arith.y"
+#line 92 "arith.y"
     { yyval = yyvsp[-2] | yyvsp[0]; }
     break;
 
   case 7:
-#line 93 "../../src/arith.y"
+#line 93 "arith.y"
     { yyval = yyvsp[-2] ^ yyvsp[0]; }
     break;
 
   case 8:
-#line 94 "../../src/arith.y"
+#line 94 "arith.y"
     { yyval = yyvsp[-2] & yyvsp[0]; }
     break;
 
   case 9:
-#line 95 "../../src/arith.y"
+#line 95 "arith.y"
     { yyval = yyvsp[-2] == yyvsp[0]; }
     break;
 
   case 10:
-#line 96 "../../src/arith.y"
+#line 96 "arith.y"
     { yyval = yyvsp[-2] > yyvsp[0]; }
     break;
 
   case 11:
-#line 97 "../../src/arith.y"
+#line 97 "arith.y"
     { yyval = yyvsp[-2] >= yyvsp[0]; }
     break;
 
   case 12:
-#line 98 "../../src/arith.y"
+#line 98 "arith.y"
     { yyval = yyvsp[-2] < yyvsp[0]; }
     break;
 
   case 13:
-#line 99 "../../src/arith.y"
+#line 99 "arith.y"
     { yyval = yyvsp[-2] <= yyvsp[0]; }
     break;
 
   case 14:
-#line 100 "../../src/arith.y"
+#line 100 "arith.y"
     { yyval = yyvsp[-2] != yyvsp[0]; }
     break;
 
   case 15:
-#line 101 "../../src/arith.y"
+#line 101 "arith.y"
     { yyval = yyvsp[-2] << yyvsp[0]; }
     break;
 
   case 16:
-#line 102 "../../src/arith.y"
+#line 102 "arith.y"
     { yyval = yyvsp[-2] >> yyvsp[0]; }
     break;
 
   case 17:
-#line 103 "../../src/arith.y"
+#line 103 "arith.y"
     { yyval = yyvsp[-2] + yyvsp[0]; }
     break;
 
   case 18:
-#line 104 "../../src/arith.y"
+#line 104 "arith.y"
     { yyval = yyvsp[-2] - yyvsp[0]; }
     break;
 
   case 19:
-#line 105 "../../src/arith.y"
+#line 105 "arith.y"
     { yyval = yyvsp[-2] * yyvsp[0]; }
     break;
 
   case 20:
-#line 106 "../../src/arith.y"
+#line 106 "arith.y"
     {
 			if (yyvsp[0] == 0)
 				yyerror("division by zero");
@@ -1240,7 +1240,7 @@ yyreduce:
     break;
 
   case 21:
-#line 111 "../../src/arith.y"
+#line 111 "arith.y"
     {
 			if (yyvsp[0] == 0)
 				yyerror("division by zero");
@@ -1249,22 +1249,22 @@ yyreduce:
     break;
 
   case 22:
-#line 116 "../../src/arith.y"
+#line 116 "arith.y"
     { yyval = !(yyvsp[0]); }
     break;
 
   case 23:
-#line 117 "../../src/arith.y"
+#line 117 "arith.y"
     { yyval = ~(yyvsp[0]); }
     break;
 
   case 24:
-#line 118 "../../src/arith.y"
+#line 118 "arith.y"
     { yyval = -(yyvsp[0]); }
     break;
 
   case 25:
-#line 119 "../../src/arith.y"
+#line 119 "arith.y"
     { yyval = yyvsp[0]; }
     break;
 
@@ -1466,7 +1466,7 @@ yyreturn:
 }
 
 
-#line 122 "../../src/arith.y"
+#line 122 "arith.y"
 
 int
 arith(s)
